@@ -1,9 +1,9 @@
 import toml
-from pathlib import Path
+import os
 
 
 def get_version():
-    path = Path(__file__).resolve().parents[1] / 'pyproject.toml'
+    path = os.path.dirname(os.path.abspath("__file__")) + '/pyproject.toml'
     pyproject = toml.loads(open(str(path)).read())
     return pyproject['tool']['poetry']['version']
 
